from tempfile import TemporaryDirectory

from homcloud.dipha import (
    DiphaInputFromFiltrationObject, DiphaOutputToIDiagramFile, DiphaOutputToDiagramFile,
    execute_dipha
)

class Filtration(object):
    """Super class of AlphaFiltration and BitmapComplex

    This class has common methods of subclasses.
    """
    def is_indexized(self):
        return bool(self.index_map)

    def write(self, output):
        """Write dipha complex or indexed complex to output.

        If self is indexized, indexed complex is written.
        If not, dipha complex is written.
        """
        if self.is_indexized():
            self.write_indexed_complex(output)
        else:
            self.write_dipha_complex(output)

    def write_file(self, path):
        with open(path, "wb") as f:
            self.write(f)

    def compute_diagram_and_save(self, outpath, parallels=1):
        """Convert filtration into diagram, and save the diagram into out.
        """
        with TemporaryDirectory() as tmpdir1, TemporaryDirectory() as tmpdir2:
            dipha_input = DiphaInputFromFiltrationObject(self, tmpdir1)
            if self.is_indexized():
                dipha_output = DiphaOutputToIDiagramFile(outpath, dipha_input, tmpdir2)
            else:
                dipha_output = DiphaOutputToDiagramFile(outpath)
            execute_dipha(dipha_input, dipha_output, parallels)
            dipha_output.output()
