
import argparse
import sys

import homcloud.pict.binarize as binarize
import homcloud.pict.utils as utils
from homcloud.base import __version__
from homcloud.license import add_argument_for_license

def argument_parser():
    """Return ArgumentParser object to parse command line arguments
    """
    p = argparse.ArgumentParser()
    p.description = "Create N-dimensional erosion-dilation filtration "
    p.add_argument("-V", "--version", action="version", version=__version__)
    p.add_argument("-T", "--type", default="text_nd",
                   help="input data format (text2d,text_nd(default),picture2d,pictures3d,npy)")
    binarize.add_argument_for_binarize_threshold(p)
    p.add_argument("-o", "--output", required=True,
                   help="output complex file name")
    p.add_argument("-s", "--ensmall", action="store_true", default=False,
                   help="ensmall binarized picture")
    p.add_argument("-I", "--combine-index-map", default=False, action="store_true",
                   help="combine the index map with the output filtration")
    p.add_argument("--metric", default="manhattan",
                   help="metric used to enlarge binarized image (manhattan(default), euclidean, etc.)")
    p.add_argument("-D", "--convert-to-diagram", default=False, action="store_true",
                   help="call dipha and directly convert to a diagram")
    add_argument_for_license(p)
    p.add_argument("input", nargs="*",
                   help="input files")
    return p

def main(args=None):
    args = args or argument_parser().parse_args()
    pict = utils.load_nd_picture(args.input, args.type)
    binary_pict = binarize.binarize_picture(pict, args.threshold, args.mode,
                                            (args.gt, args.lt))
    bitmap = binarize.distance_bitmap(binary_pict, args.metric, args.ensmall)

    if args.combine_index_map:
        bitmap.indexize()

    if args.convert_to_diagram:
        bitmap.compute_diagram_and_save(args.output)
    else:
        bitmap.write_file(args.output)

    return 0

if __name__ == '__main__':
    sys.exit(main())
