import argparse

from homcloud.pict import utils
from homcloud.bitmap_complex import BitmapComplex
from homcloud.base import __version__
from homcloud.license import add_argument_for_license

def main(args=None):
    args = args or argument_parser().parse_args()
    pict = utils.load_nd_picture(args.input, args.type)
    if args.mode == "superlevel":
        pict = -pict.astype(float)
        upper_bound = -args.lower_bound
        lower_bound = -args.upper_bound
        flip_sign = True
    elif args.mode == "sublevel":
        upper_bound = args.upper_bound
        lower_bound = args.lower_bound
        flip_sign = False
    else:
        raise RuntimeError("mode must be superlevel or subelvel")

    pict[pict > upper_bound] = upper_bound
    pict[pict < lower_bound] = lower_bound

    bitmap = BitmapComplex(pict, flip_sign)

    if args.combine_index_map:
        bitmap.indexize()

    if args.convert_to_diagram:
        bitmap.compute_diagram_and_save(args.output)
    else:
        bitmap.write_file(args.output)

def argument_parser():
    p = argparse.ArgumentParser()
    p.add_argument("-V", "--version", action="version", version=__version__)
    p.add_argument("-m", "--mode", default="sublevel",
                   help="the way to construct dipha complex (sublevel(default),superlevel)")
    p.add_argument("-u", "--upper-bound", type=float, default=255,
                   help="upper bound of pixel value")
    p.add_argument("-l", "--lower-bound", type=float, default=0,
                   help="lower bound of pixel value")
    p.add_argument("-I", "--combine-index-map", default=False, action="store_true",
                   help="combine the index map with the output filtration")
    p.add_argument("-T", "--type", default="text_nd",
                   help="input data format (text2d,text_nd(default),picture2d,pictures3d,npy)")
    p.add_argument("-D", "--convert-to-diagram", default=False, action="store_true",
                   help="call dipha and directly convert to a diagram")
    p.add_argument("-o", "--output", required=True,
                   help="output file")
    add_argument_for_license(p)
    p.add_argument("input", nargs="*", help="input files")
    return p

if __name__ == "__main__":
    main()
