import enum
import os
import struct

@enum.unique
class FileType(enum.Enum):
    text = 0
    dipha_complex = 1
    dipha_diagram = 2
    idipha_complex = 3
    idipha_diagram = 4
    unknown = 5

def estimate_complex_file_type(typestr, path):
    TABLE_TYPENAME = {
        "idipha": FileType.idipha_complex,
        "dipha": FileType.dipha_complex
    }

    TABLE_EXTENSION = {
        ".icomplex": FileType.idipha_complex,
        ".complex": FileType.dipha_complex,
    }

    _, ext = os.path.splitext(path)
    return TABLE_TYPENAME.get(typestr) or TABLE_EXTENSION.get(ext) or FileType.dipha_complex

def read_diagram_header(f):
    magic, filetype = struct.unpack("qq", f.read(16))
    if magic != 8067171840 or filetype != 2:
        raise RuntimeError("This file is not a dipha diagram file")
    num_pairs, = struct.unpack("q", f.read(8))
    return num_pairs
